##  Example Configurations
Example 1: Synchronize Business Applications from SAP LeanIX to Jira Service Management Parameter | Value
---|---
Source system |  SAP LeanIX
Fact sheet type in SAP LeanIX | Business application (subtype of application)
Object type in Jira Service Management | Business application
Field mappings |
  * name - Name
  * alias - Alias
  * description - Description




Example 2: Synchronize IT Components from Jira Service Management to SAP LeanIX Parameter | Value
---|---
Source system | Jira Service Management
Fact sheet type in SAP LeanIX | Software (subtype of IT component)
Object type in Jira Service Management | Software
Field mappings |
  * name - Name
  * description - Description




